@@ -64,9 +64,7 @@ function set_config()
 		put_param ${IFCFG} "routes_${VENET_DEV}" "default"
 	else
 		put_param3 ${IFCFG} "config_${VENET_DEV}" ""
-		put_param3 ${IFCFG} "routes_${VENET_DEV}" \
-			"-net ${FAKEGATEWAYNET}/24" # dev ${VENET_DEV}
-		add_param3 ${IFCFG} "routes_${VENET_DEV}" "default via ${FAKEGATEWAY}"
+		add_param3 ${IFCFG} "routes_${VENET_DEV}" "default"
 	fi
 }
 
@@ -101,11 +99,12 @@ function add_ip()
 	fi
 
 	for ip in ${IP_ADDR}; do
+		if [ "${ip#*:}" = "$ip" ]; then nm=32; else nm=0; fi
 		if ! grep -qw "config_${VENET_DEV}=\(.*\"${ip}[\"\/].*\)" ${IFCFG}; then
 			if ! is_baselayout1 ; then
-				add_param "${IFCFG}" "config_${VENET_DEV}" "${ip}/32"
+				add_param "${IFCFG}" "config_${VENET_DEV}" "${ip}/${nm}"
 			else
-				add_param3 "${IFCFG}" "config_${VENET_DEV}" "${ip}/32"
+				add_param3 "${IFCFG}" "config_${VENET_DEV}" "${ip}/${nm}"
 			fi
 		fi
 	done
