@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,36 +18,28 @@
 #ifndef _VZCTL_H_
 #define _VZCTL_H_
 
-/* Action numeration should begin with 1. Value 0 is reserved. */
-#define ACTION_CREATE		1
-#define ST_CREATE		"creating"
-#define ACTION_DESTROY		2
-#define ST_DESTROY		"destroying"
-#define ACTION_MOUNT		3
-#define ST_MOUNT		"mounting"
-#define ACTION_UMOUNT		4
-#define ST_UMOUNT		"unmounting"
-#define ACTION_START		5
-#define ST_START		"starting"
-#define ACTION_STOP		6
-#define ST_STOP			"stopping"
-#define ACTION_RESTART		7
-#define ST_RESTART		"restarting"
-#define ACTION_SET		8
-#define ST_SET			"setting"
-#define ACTION_STATUS		9
-#define ACTION_EXEC		10
-#define ACTION_EXEC2		11
-#define ACTION_EXEC3		12
-#define ACTION_ENTER		13
-#define ST_QUOTA_INIT		"initializing-quota"
-#define	ACTION_RUNSCRIPT	14
-#define	ACTION_CUSTOM		15
-#define ACTION_CHKPNT		16
-#define ACTION_RESTORE		17
-#define ACTION_QUOTAON		18
-#define ACTION_QUOTAOFF		19
-#define ACTION_QUOTAINIT	20
+typedef enum {
+	ACTION_CREATE		= 1,
+	ACTION_DESTROY,
+	ACTION_MOUNT,
+	ACTION_UMOUNT,
+	ACTION_START,
+	ACTION_STOP,
+	ACTION_RESTART,
+	ACTION_SET,
+	ACTION_STATUS,
+	ACTION_EXEC,
+	ACTION_EXEC2,
+	ACTION_EXEC3,
+	ACTION_ENTER,
+	ACTION_RUNSCRIPT,
+	ACTION_CUSTOM,
+	ACTION_CHKPNT,
+	ACTION_RESTORE,
+	ACTION_QUOTAON,
+	ACTION_QUOTAOFF,
+	ACTION_QUOTAINIT
+} act_t;
 
 /* default cpu units values */
 #define LHTCPUUNITS		250
