@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2011, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -93,7 +93,6 @@ static int dev_create(const char *root, dev_res *dev)
 
 int set_devperm(vps_handler *h, envid_t veid, dev_res *dev)
 {
-	int ret;
 	struct vzctl_setdevperms devperms;
 
 	devperms.veid = veid;
@@ -101,41 +100,12 @@ int set_devperm(vps_handler *h, envid_t veid, dev_res *dev)
 	devperms.mask = dev->mask;
 	devperms.type = dev->type;
 
-	if ((ret = ioctl(h->vzfd, VZCTL_SETDEVPERMS, &devperms)))
-		logger(-1, errno, "Unable to set devperms");
-
-	return ret;
-}
-
-struct vzctl_ve_configure_pci {
-	struct vzctl_ve_configure conf;
-	struct vzctl_ve_pci_dev dev;
-};
-
-static int set_pci(vps_handler *h, envid_t veid, int op, char *dev_id)
-{
-	int ret;
-	struct vzctl_ve_configure_pci conf_pci;
-	struct vzctl_ve_configure *conf = &conf_pci.conf;
-	struct vzctl_ve_pci_dev *dev = &conf_pci.dev;
-
-	sscanf(dev_id, "%x:%x:%x.%d", &dev->domain, &dev->bus,
-					&dev->slot, &dev->func);
-	conf->veid = veid;
-	if (op == ADD)
-		conf->key = VE_CONFIGURE_ADD_PCI_DEVICE;
-	else
-		conf->key = VE_CONFIGURE_DEL_PCI_DEVICE;
-	conf->val = 0;
-	conf->size = sizeof(struct vzctl_ve_pci_dev);
-
-	if ((ret = ioctl(h->vzfd, VZCTL_VE_CONFIGURE, &conf_pci))) {
-		if (errno == EEXIST)
-			return 0;
-		logger(-1, errno, "Unable to move pci device %s", dev_id);
+	if (ioctl(h->vzfd, VZCTL_SETDEVPERMS, &devperms)) {
+		logger(-1, errno, "Error setting device permissions");
+		return VZ_SET_DEVICES;
 	}
 
-	return ret;
+	return 0;
 }
 
 /** Allow/disallow access to devices on host system from CT.
@@ -164,10 +134,11 @@ int vps_set_devperm(vps_handler *h, envid_t veid, const char *root,
 	list_for_each(res, dev_h, list) {
 		if (res->name)
 			if ((ret = dev_create(root, res)))
-				break;
+				goto out;
 		if ((ret = set_devperm(h, veid, res)))
-			break;
+			goto out;
 	}
+out:
 	return ret;
 }
 
@@ -204,7 +175,8 @@ void free_dev_param(dev_param *dev)
 	free_dev(&dev->dev);
 }
 
-int run_pci_script(envid_t veid, int op, list_head_t *pci_h)
+int run_pci_script(envid_t veid, int op, list_head_t *pci_h,
+		const char *ve_root)
 {
 	char *argv[3];
 	char *envp[10];
@@ -217,6 +189,8 @@ int run_pci_script(envid_t veid, int op, list_head_t *pci_h)
 		return 0;
 	snprintf(buf, sizeof(buf), "VEID=%d", veid);
 	envp[i++] = strdup(buf);
+	snprintf(buf, sizeof(buf), "VE_ROOT=%s", ve_root);
+	envp[i++] = strdup(buf);
 	snprintf(buf, sizeof(buf), "ADD=%d", op == ADD);
 	envp[i++] = strdup(buf);
 	envp[i++] = list2str("PCI", pci_h);
@@ -234,9 +208,7 @@ int run_pci_script(envid_t veid, int op, list_head_t *pci_h)
 int vps_set_pci(vps_handler *h, envid_t veid, int op, const char *root,
 		pci_param *pci)
 {
-	int ret = 0;
 	list_head_t *pci_h = &pci->list;
-	str_param *res;
 
 	if (list_empty(pci_h))
 		return 0;
@@ -248,10 +220,5 @@ int vps_set_pci(vps_handler *h, envid_t veid, int op, const char *root,
 	}
 	logger(0, 0, "Setting PCI devices");
 
-	list_for_each(res, pci_h, list)
-		if ((ret = set_pci(h, veid, op, res->val)))
-			break;
-	if (!ret)
-		ret = run_pci_script(veid, op, pci_h);
-	return ret;
+	return run_pci_script(veid, op, pci_h, root);
 }
