@@ -60,12 +60,11 @@ static int veth_dev_mac_filter(vps_handler *h, envid_t veid, veth_dev *dev)
 static int veth_dev_create(vps_handler *h, envid_t veid, veth_dev *dev)
 {
 	struct vzctl_ve_hwaddr veth;
-	int ret;
 
 	if (!dev->dev_name[0] || dev->addrlen != ETH_ALEN)
-		return EINVAL;
+		return VZ_VETH_ERROR;
 	if (dev->addrlen_ve != 0 && dev->addrlen_ve != ETH_ALEN)
-		return EINVAL;
+		return VZ_VETH_ERROR;
 	veth.op = VE_ETH_ADD;
 	veth.veid = veid;
 	veth.addrlen = dev->addrlen;
@@ -74,8 +73,7 @@ static int veth_dev_create(vps_handler *h, envid_t veid, veth_dev *dev)
 	memcpy(veth.dev_addr_ve, dev->dev_addr_ve, ETH_ALEN);
 	memcpy(veth.dev_name, dev->dev_name, IFNAMSIZE);
 	memcpy(veth.dev_name_ve, dev->dev_name_ve, IFNAMSIZE);
-	ret = ioctl(h->vzfd, VETHCTL_VE_HWADDR, &veth);
-	if (ret) {
+	if (ioctl(h->vzfd, VETHCTL_VE_HWADDR, &veth) != 0) {
 		if (errno == ENOTTY) {
 			logger(-1, 0, "Error: veth feature is"
 				" not supported by kernel");
@@ -84,9 +82,10 @@ static int veth_dev_create(vps_handler *h, envid_t veid, veth_dev *dev)
 		} else {
 			logger(-1, errno, "Unable to create veth");
 		}
-		ret = VZ_VETH_ERROR;
+		return VZ_VETH_ERROR;
 	}
-	return ret;
+
+	return 0;
 }
 
 static int veth_dev_remove(vps_handler *h, envid_t veid, veth_dev *dev)
